# kataria

## name. why?
- **Kataria anisodonta**, the oldest known ancestor of today's pythons
- [**Katari**](https://en.wikipedia.org/wiki/Amaru_(mythology) ([aymara](https://en.wikipedia.org/wiki/Aymara_language)), a winged mythological snake

## library. why?

is your brain oxidized beyond repair?
did you get hooked on doing parts of your code in a functional style?
are you tired of list comprehensions and for loops?
do you have to write something in python regardless?

*kataria* lets you apply most of the concepts from rust in python

check out the tests for some ideas on how to use this library.
I'll write proper docs if people actually express further interest in this.

